Documentation
¶
Overview ¶
SPDX-License-Identifier: BSD-3-Clause Copyright (c) 2022, Unikraft GmbH and The KraftKit Authors. Licensed under the BSD-3-Clause License (the "License"). You may not use this file except in compliance with the License.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type MenuOptions ¶
type MenuOptions struct {
Architecture string `long:"arch" short:"m" usage:"Filter the creation of the build by architecture of known targets"`
ForcePull bool `long:"force-pull" usage:"Force pulling components before opening the menu"`
Frontend string `long:"frontend" short:"f" usage:"Alternative frontend to use for the configuration editor" default:"menuconfig"`
Kraftfile string `long:"kraftfile" short:"K" usage:"Set an alternative path of the Kraftfile"`
NoCache bool `long:"no-cache" usage:"Do not use the cache when pulling dependencies"`
NoConfigure bool `long:"no-configure" usage:"Do not run Unikraft's configure step before building"`
Platform string `long:"plat" short:"p" usage:"Filter the creation of the build by platform of known targets"`
Target string `long:"target" short:"t" usage:"Build a particular known target"`
// contains filtered or unexported fields
}
Click to show internal directories.
Click to hide internal directories.