Documentation
¶
Overview ¶
SPDX-License-Identifier: BSD-3-Clause Copyright (c) 2022, Unikraft GmbH and The KraftKit Authors. Licensed under the BSD-3-Clause License (the "License"). You may not use this file except in compliance with the License.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type ListOptions ¶
type ListOptions struct {
All bool `long:"all" usage:"Show everything"`
Arch string `long:"arch" usage:"Set a specific arhitecture to list for"`
Kraftfile string `long:"kraftfile" short:"K" usage:"Set an alternative path of the Kraftfile"`
Limit int `long:"limit" short:"l" usage:"Set the maximum number of results" default:"50"`
Local bool `long:"local" usage:"Show local packages only"`
NoLimit bool `long:"no-limit" usage:"Do not limit the number of items to print"`
Output string `long:"output" short:"o" usage:"Set output format. Options: table,yaml,json,list" default:"table"`
Plat string `long:"plat" usage:"Set a specific platform to list for"`
Remote bool `long:"remote" short:"u" usage:"Show remote packages only"`
ShowApps bool `long:"apps" short:"" usage:"Show applications"`
ShowArchs bool `long:"archs" short:"M" usage:"Show architectures"`
ShowCore bool `long:"core" short:"C" usage:"Show Unikraft core versions"`
ShowLibs bool `long:"libs" short:"L" usage:"Show libraries"`
ShowPlats bool `long:"plats" short:"P" usage:"Show platforms"`
Update bool `long:"update" short:"U" usage:"Update package indexes before listing"`
}
Click to show internal directories.
Click to hide internal directories.