Documentation
¶
Overview ¶
SPDX-License-Identifier: BSD-3-Clause Copyright (c) 2022, Unikraft GmbH and The KraftKit Authors. Licensed under the BSD-3-Clause License (the "License"). You may not use this file except in compliance with the License.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type PullOptions ¶
type PullOptions struct {
All bool `long:"all" short:"A" usage:"Pull all versions"`
Architecture string `long:"arch" short:"m" usage:"Specify the desired architecture"`
Format string `long:"as" short:"f" usage:"Set the package format" default:"auto"`
KConfig []string `long:"kconfig" short:"k" usage:"Request a package with specific KConfig options."`
Kraftfile string `long:"kraftfile" short:"K" usage:"Set an alternative path of the Kraftfile"`
NoChecksum bool `long:"no-checksum" short:"C" usage:"Do not verify package checksum (if available)"`
Output string `long:"output" short:"o" usage:"Save the package contents to the provided directory"`
Platform string `long:"plat" short:"p" usage:"Specify the desired platform"`
Update bool `long:"update" short:"u" usage:"Perform an update which gathers remote sources"`
Workdir string `long:"workdir" short:"w" usage:"Set a path to working directory to pull components to"`
}
Click to show internal directories.
Click to hide internal directories.